@@ -273,7 +273,12 @@ void ImagePreview::updateScaleFactors()
 
     // Calculate a scale factor from the original image's size and it's current preview
     QSize actualSize = getActualImageSize();
+    // TODO(jzarl): remove once we don't care about Debian 11 anymore:
+#if QT_DEPRECATED_SINCE(5, 15)
     QSize previewSize = pixmap()->size();
+#else
+    QSize previewSize = pixmap().size();
+#endif
     m_scaleWidth = double(actualSize.width()) / double(previewSize.width());
     m_scaleHeight = double(actualSize.height()) / double(previewSize.height());
 
@@ -389,7 +394,7 @@ void ImagePreview::createNewArea(QRect geometry, QRect actualGeometry)
     actualGeometry = areaPreviewToActual(newArea->geometry());
     // Store the coordinates on the real image (not on the preview)
     newArea->setActualCoordinates(actualGeometry);
-    emit areaCreated(newArea);
+    Q_EMIT areaCreated(newArea);
 
     newArea->show();
     newArea->showContextMenu();
@@ -465,7 +470,7 @@ void ImagePreview::createTaggedArea(QString category, QString tag, QRect geometr
     // Create a ResizableFrame (cleaned up in Dialog::tidyAreas())
     ResizableFrame *newArea = new ResizableFrame(this);
 
-    emit areaCreated(newArea);
+    Q_EMIT areaCreated(newArea);
 
     newArea->setGeometry(areaActualToPreview(geometry));
     newArea->setActualCoordinates(geometry);
@@ -531,7 +536,7 @@ void ImagePreview::acceptProposedTag(QPair<QString, QString> tagData, ResizableF
 
     // Tell all ListSelects that we accepted a proposed tag, so that the ListSelect
     // holding the respective category can ensure that the tag is checked
-    emit proposedTagSelected(tagData.first, tagData.second);
+    Q_EMIT proposedTagSelected(tagData.first, tagData.second);
 
     // Associate the area with the proposed tag
     area->setTagData(tagData.first, tagData.second);
