@@ -411,7 +411,8 @@ void AnnotationDialog::ListSelect::showContextMenu(const QPoint &pos)
         deleteAction->setEnabled(false);
         renameAction->setEnabled(false);
         members->setEnabled(false);
-        newCategoryAction->setEnabled(false);
+        if (newCategoryAction)
+            newCategoryAction->setEnabled(false);
         newSubcategoryAction->setEnabled(false);
         if (takeAction)
             takeAction->setEnabled(false);
@@ -636,7 +637,7 @@ void AnnotationDialog::ListSelect::populateAlphaTree()
     DB::CategoryItemPtr item = m_category->itemsCategories();
 
     m_treeWidget->setRootIsDecorated(true);
-    addItems(item.data(), 0);
+    addItems(item.data(), nullptr);
     m_treeWidget->sortByColumn(0, Qt::AscendingOrder);
     m_treeWidget->setSortingEnabled(true);
 }
@@ -713,7 +714,7 @@ QTreeWidgetItem *AnnotationDialog::ListSelect::getUntaggedImagesTag()
 
     // Be sure not to crash here in case the config points to a non-existent tag
     if (matchingTags.at(0) == nullptr) {
-        return 0;
+        return nullptr;
     } else {
         return matchingTags.at(0);
     }
