@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2012 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2012-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef BACKGROUNDJOBS_EXTRACTONETHUMBNAILJOB_H
 #define BACKGROUNDJOBS_EXTRACTONETHUMBNAILJOB_H
@@ -30,7 +29,7 @@ public:
     int index() const;
     void cancel();
 
-private slots:
+private Q_SLOTS:
     void frameLoaded(const QImage &);
 
 private:
