@@ -1,7 +1,7 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #ifndef CATEGORYLISTVIEW_DragableTreeWidget_H
 #define CATEGORYLISTVIEW_DragableTreeWidget_H
 #include <DB/CategoryPtr.h>
@@ -25,7 +25,7 @@ protected:
     bool dropMimeData(QTreeWidgetItem *parent, int index, const QMimeData *data, Qt::DropAction action) override;
     void dragMoveEvent(QDragMoveEvent *event) override;
 
-signals:
+Q_SIGNALS:
     void itemsChanged();
 
 private:
