@@ -1,13 +1,21 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2003-2012 Jesper K. Pedersen <jesper.pedersen@kdab.com>
+// SPDX-FileCopyrightText: 2007 Dirk Mueller <mueller@kde.org>
+// SPDX-FileCopyrightText: 2007-2008 Jan Kundrát <jkt@flaska.net>
+// SPDX-FileCopyrightText: 2007-2010 Tuomas Suutari <tuomas@nepnep.net>
+// SPDX-FileCopyrightText: 2008 Henner Zeller <h.zeller@acm.org>
+// SPDX-FileCopyrightText: 2011 Andreas Neustifter <andreas.neustifter@gmail.com>
+// SPDX-FileCopyrightText: 2013-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2017-2018 Robert Krawitz <rlk@alum.mit.edu>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef NEWIMAGEFINDER_H
 #define NEWIMAGEFINDER_H
 #include "ImageInfo.h"
 #include "ImageInfoPtr.h"
 
+#include <QMutex>
+
 namespace DB
 {
 class MD5Map;
@@ -34,6 +42,7 @@ private:
     QString m_modifiedFileCompString;
     QRegExp m_modifiedFileComponent;
     QStringList m_originalFileComponents;
+    static QMutex s_imageFinderLock; ///< Only one NewImageFinder can accesss the database at any time!
 };
 }
 
