@@ -71,9 +71,9 @@ void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
     QFile out(fileName + QStringLiteral(".tmp"));
     if (!out.open(QIODevice::WriteOnly | QIODevice::Text)) {
         m_db->uiDelegate().error(
-            DB::LogMessage { DBLog(), QStringLiteral("Error saving to file '%1': %2").arg(out.fileName()).arg(out.errorString()) }, i18n("<p>Could not save the image database to XML.</p>"
-                                                                                                                                         "File %1 could not be opened because of the following error: %2",
-                                                                                                                                         out.fileName(), out.errorString()),
+            DB::LogMessage { DBLog(), QStringLiteral("Error saving to file '%1': %2").arg(out.fileName(), out.errorString()) }, i18n("<p>Could not save the image database to XML.</p>"
+                                                                                                                                     "File %1 could not be opened because of the following error: %2",
+                                                                                                                                     out.fileName(), out.errorString()),
             i18n("Error while saving..."));
         return;
     }
@@ -97,6 +97,7 @@ void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
         saveBlockList(writer);
         saveMemberGroups(writer);
         // saveSettings(writer);
+        saveGlobalSortOrder(writer);
     }
     writer.writeEndDocument();
     qCDebug(TimingLog) << "DB::FileWriter::save(): Saving took" << timer.elapsed() << "ms";
@@ -127,12 +128,12 @@ void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
 
 void DB::FileWriter::saveCategories(QXmlStreamWriter &writer)
 {
-    QStringList categories = DB::ImageDB::instance()->categoryCollection()->categoryNames();
+    const QStringList categories = DB::ImageDB::instance()->categoryCollection()->categoryNames();
     ElementWriter dummy(writer, QStringLiteral("Categories"));
 
     DB::CategoryPtr tokensCategory = DB::ImageDB::instance()->categoryCollection()->categoryForSpecial(DB::Category::TokensCategory);
     const DB::TagInfo *untaggedTag = DB::ImageDB::instance()->untaggedTag();
-    for (QString name : categories) {
+    for (const QString &name : categories) {
         DB::CategoryPtr category = DB::ImageDB::instance()->categoryCollection()->categoryForName(name);
 
         if (!shouldSaveCategory(name)) {
@@ -264,6 +265,16 @@ void DB::FileWriter::saveMemberGroups(QXmlStreamWriter &writer)
     }
 }
 
+void DB::FileWriter::saveGlobalSortOrder(QXmlStreamWriter &writer)
+{
+    ElementWriter dummy(writer, QStringLiteral("global-sort-order"));
+    for (const auto &item : m_db->categoryCollection()->globalSortOrder()->modifiedSortOrder()) {
+        ElementWriter dummy(writer, QStringLiteral("item"));
+        writer.writeAttribute(QStringLiteral("category"), item.category);
+        writer.writeAttribute(QStringLiteral("item"), item.item);
+    }
+}
+
 /*
 Perhaps, we may need this later ;-)
 
