@@ -293,7 +293,7 @@ void ImportDialog::next()
 {
     if (currentPage() == m_destinationPage) {
         QString dir = m_destinationEdit->text();
-        if (!QFileInfo(dir).exists()) {
+        if (!QFileInfo::exists(dir)) {
             const QString question = i18n("Folder %1 does not exist. Should it be created?", dir);
             const QString title = i18nc("@title", "Create folder?");
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
